@@ -2,7 +2,7 @@ from cellar_extractor.json_to_csv import read_csv
 from cellar_extractor.fulltext_saving import add_sections
 
 def extra_cellar(data=None,filepath=None, threads=10):
-    if not data:
+    if data is not None:
         data = read_csv(filepath)
     if filepath:
         add_sections(data, threads, filepath.replace(".csv", "_fulltext.json"))
